#!/bin/bash

# Usage:
#  ./test-runner.sh <IMG_URL> <BACKEND> [<TEST> [<TEST> ...]]
#
# Example:
#  ./test-runner.sh file:///test.img openstack tests/uname.test

set -e

# Inputs
URL="$1"
FILE="$(basename "$URL")"
shift
BACKEND="$1"
shift
TEST_FILES=( "$@" )

# Write log header
echo "==============================================================================="
echo "Testing image $FILE on $(date)"
echo "  with test command files: ${TEST_FILES[@]}"
echo "==============================================================================="

# Fetch the image
echo "Fetching image $FILE"
curl -o "$FILE" "$URL"

# Run the test
echo "Launching $BACKEND test backend"
"$BACKEND/do-tests.sh" "$FILE" "${TEST_FILES[@]}" 2>&1

# Delete the test image
echo "Deleting local image $FILE"
rm "$FILE"

# Write log footer
echo "==============================================================================="
echo "$(date): Finished testing: SUCCESS!"
echo "==============================================================================="
